<?php
/**
 * @package    hubzero-cms
 * @copyright  Copyright (c) 2005-2020 The Regents of the University of California.
 * @license    http://opensource.org/licenses/MIT MIT
 */

defined('_HZEXEC_') or die();

$base = 'index.php?option=' . $this->option . '&cn=' . $this->group->get('cn') . '&active=forum&scope=' . $this->filters['section'] . '/' . $this->filters['category'];

if (!function_exists('sortDir'))
{
	/**
	 * Returns opposite of how it was sorted
	 *
	 * @param  array  $filters  Array of filters
	 * @param  string $current  
	 * @param  string $dir      Direction of order
	 * @return string
	 */
	function sortDir($filters, $current, $dir='DESC')
	{
		if ($filters['sortby'] == $current && $filters['sort_Dir'] == $dir)
		{
			$dir = ($dir == 'ASC' ? 'DESC' : 'ASC');
		}
		return strtolower($dir);
	}
}

// prepare the URL parameters for the delete URLS to retain the sorting
$sortingValues = (object) ['sortdir' => $this->filters['sort_Dir'], 'sortby' => $this->filters['sortby'], 'start' => $this->filters['start'], 'limit' => $this->filters['limit']];
$sortingQueryString = '';
if (!empty($sortingValues->sortby) || !empty($sortingValues->start || !empty($sortingValues->limit)))
{
	$sortingQueryString = '?' . http_build_query($sortingValues);
}

$this->category->set('section_alias', $this->filters['section']);

$this->css()
     ->js();
?>

<ul id="page_options">
	<li>
		<a class="icon-folder categories btn" href="<?php echo Route::url('index.php?option=' . $this->option . '&cn=' . $this->group->get('cn') . '&active=forum'); ?>">
			<?php echo Lang::txt('PLG_GROUPS_FORUM_ALL_CATEGORIES'); ?>
		</a>
	</li>
</ul>

<section class="main section">
	<form action="<?php echo Route::url('index.php?option=' . $this->option . '&cn=' . $this->group->get('cn') . '&active=forum&scope=search'); ?>" method="get">
		<div class="container data-entry">
			<input class="entry-search-submit" type="submit" value="<?php echo Lang::txt('PLG_GROUPS_FORUM_SEARCH'); ?>" />
			<fieldset class="entry-search">
				<legend><?php echo Lang::txt('PLG_GROUPS_FORUM_SEARCH_LEGEND'); ?></legend>
				<label for="entry-search-field"><?php echo Lang::txt('PLG_GROUPS_FORUM_SEARCH_LABEL'); ?></label>
				<input type="text" name="q" id="entry-search-field" value="<?php echo $this->escape($this->filters['search']); ?>" placeholder="<?php echo Lang::txt('PLG_GROUPS_FORUM_SEARCH_PLACEHOLDER'); ?>" />
			</fieldset>
		</div><!-- / .container -->
	</form>
	<form action="<?php echo Route::url($this->category->link()); ?>" method="get">

		<?php if ($this->category->get('closed')) { ?>
			<p class="warning">
				<?php echo Lang::txt('PLG_GROUPS_FORUM_CATEGORY_CLOSED'); ?>
			</p>
		<?php } ?>

		<div class="container">
			<nav class="entries-filters" aria-label="<?php echo Lang::txt('JGLOBAL_FILTER_AND_SORT_RESULTS'); ?>">
				<ul class="entries-menu order-options">
					<li>
						<a class="<?php echo $this->filters['sortby'] == 'created' ? 'active ' . strtolower($this->filters['sort_Dir']) : sortDir($this->filters, 'created'); ?>" href="<?php echo Route::url($base . '&sortby=created&sortdir=' . sortDir($this->filters, 'created')); ?>" title="<?php echo Lang::txt('PLG_GROUPS_FORUM_SORT_BY_CREATED'); ?>">
							<?php echo Lang::txt('PLG_GROUPS_FORUM_SORT_CREATED'); ?>
						</a>
					</li>
					<li>
						<a class="<?php echo $this->filters['sortby'] == 'activity' ? 'active ' . strtolower($this->filters['sort_Dir']) : sortDir($this->filters, 'activity'); ?>" href="<?php echo Route::url($base . '&sortby=activity&sortdir=' . sortDir($this->filters, 'activity')); ?>" title="<?php echo Lang::txt('PLG_GROUPS_FORUM_SORT_BY_ACTIVITY'); ?>">
							<?php echo Lang::txt('PLG_GROUPS_FORUM_SORT_ACTIVITY'); ?>
						</a>
					</li>
					<li>
						<a class="<?php echo $this->filters['sortby'] == 'replies' ? 'active ' . strtolower($this->filters['sort_Dir']) : sortDir($this->filters, 'replies'); ?>" href="<?php echo Route::url($base . '&sortby=replies&sortdir=' . sortDir($this->filters, 'replies')); ?>" title="<?php echo Lang::txt('PLG_GROUPS_FORUM_SORT_BY_NUM_POSTS'); ?>">
							<?php echo Lang::txt('PLG_GROUPS_FORUM_SORT_NUM_POSTS'); ?>
						</a>
					</li>
					<li>
						<a class="<?php echo $this->filters['sortby'] == 'title' ? 'active ' . strtolower($this->filters['sort_Dir']) : sortDir($this->filters, 'title', 'ASC'); ?>" href="<?php echo Route::url($base . '&sortby=title&sortdir=' . sortDir($this->filters, 'title', 'ASC')); ?>" title="<?php echo Lang::txt('PLG_GROUPS_FORUM_SORT_BY_TITLE'); ?>">
							<?php echo Lang::txt('PLG_GROUPS_FORUM_SORT_TITLE'); ?>
						</a>
					</li>
				</ul>
			</nav>

			<table class="entries">
				<caption>
					<?php
					if ($this->filters['search'])
					{
						if ($this->category->get('title'))
						{
							echo Lang::txt('PLG_GROUPS_FORUM_SEARCH_FOR_IN', $this->escape($this->filters['search']), $this->escape(stripslashes($this->category->get('title'))));
						}
						else
						{
							echo Lang::txt('PLG_GROUPS_FORUM_SEARCH_FOR', $this->escape($this->filters['search']));
						}
					}
					else
					{
						echo Lang::txt('PLG_GROUPS_FORUM_SEARCH_IN', $this->escape(stripslashes($this->category->get('title'))));
					}
					?>
				</caption>
				<?php if (!$this->category->get('closed') && $this->config->get('access-create-thread')) { ?>
					<thead>
						<tr>
							<td colspan="<?php echo ($this->config->get('access-delete-thread') || $this->config->get('access-edit-thread')) ? '5' : '4'; ?>">
								<a class="icon-add add btn" href="<?php echo Route::url($base . '/new'); ?>">
									<?php echo Lang::txt('PLG_GROUPS_FORUM_NEW_DISCUSSION'); ?>
								</a>
							</td>
						</tr>
					</thead>
					<?php if (count($this->threads) > 10) {?>
					<tfoot>
						<tr>
							<td colspan="<?php echo ($this->config->get('access-delete-thread') || $this->config->get('access-edit-thread')) ? '5' : '4'; ?>">
								<a class="icon-add add btn" href="<?php echo Route::url($base . '/new'); ?>">
									<?php echo Lang::txt('PLG_GROUPS_FORUM_NEW_DISCUSSION'); ?>
								</a>
							</td>
						</tr>
					</tfoot>
					<?php }
				} ?>
				<tbody>
					<?php
					if ($this->threads->count() > 0)
					{
						foreach ($this->threads as $row)
						{
							$name = Lang::txt('JANONYMOUS');
							if (!$row->get('anonymous'))
							{
								$name = $this->escape(stripslashes($row->creator->get('name', $name)));
								if (in_array($row->creator->get('access'), User::getAuthorisedViewLevels()))
								{
									$name = '<a href="' . Route::url($row->creator->link()) . '">' . $name . '</a>';
								}
							}
							$cls = array();
							if ($row->isClosed())
							{
								$cls[] = 'closed';
							}
							if ($row->isSticky())
							{
								$cls[] = 'sticky';
							}

							$row->set('category', $this->filters['category']);
							$row->set('section', $this->filters['section']);
							?>
							<tr<?php if (count($cls) > 0) { echo ' class="' . implode(' ', $cls) . '"'; } ?>>
								<th class="priority-5">
									<span class="entry-id"><?php echo $this->escape($row->get('id')); ?></span>
								</th>
								<td>
									<a class="entry-title" href="<?php echo Route::url($base . '/' . $row->get('id')); ?>">
										<span><?php echo $this->escape(stripslashes($row->get('title'))); ?></span>
									</a>
									<span class="entry-details">
										<span class="entry-date">
											<time datetime="<?php echo $row->created(); ?>"><?php echo $row->created('date'); ?></time>
										</span>
										<?php echo Lang::txt('PLG_GROUPS_FORUM_BY_USER', '<span class="entry-author">' . $name . '</span>'); ?>
									</span>
								</td>
								<td class="priority-4">
									<span><?php
									echo $row->thread()
										->whereEquals('state', $row->get('state'))
										->whereIn('access', $this->filters['access'])
										->total();
									?></span>
									<span class="entry-details">
										<?php echo Lang::txt('PLG_GROUPS_FORUM_COMMENTS'); ?>
									</span>
								</td>
								<td class="priority-3">
									<span><?php echo Lang::txt('PLG_GROUPS_FORUM_LAST_POST'); ?></span>
									<span class="entry-details">
										<?php
										$lastpost = $row->lastActivity();
										if ($lastpost->get('id'))
										{
											$lname = Lang::txt('JANONYMOUS');
											if (!$lastpost->get('anonymous'))
											{
												$lname = $this->escape(stripslashes($lastpost->creator->get('name')));
												if (in_array($lastpost->creator->get('access'), User::getAuthorisedViewLevels()))
												{
													$lname = '<a href="' . Route::url($lastpost->creator->link()) . '">' . $lname . '</a>';
												}
											}
											?>
											<span class="entry-date">
												<time datetime="<?php echo $lastpost->created(); ?>"><?php echo $lastpost->created('date'); ?></time>
											</span>
											<?php echo Lang::txt('PLG_GROUPS_FORUM_BY_USER', '<span class="entry-author">' . $lname . '</span>'); ?>
										<?php } else { ?>
											<?php echo Lang::txt('PLG_GROUPS_FORUM_NONE'); ?>
										<?php } ?>
									</span>
								</td>
								<?php if ($this->group->published == 1) { ?>
									<?php if ($this->config->get('access-delete-thread') || $this->config->get('access-edit-thread') || User::get('id') == $row->get('created_by')) { ?>
										<td class="entry-options">
											<?php if ($row->get('created_by') == User::get('id') || $this->config->get('access-edit-thread')) { ?>
												<a class="icon-edit edit" href="<?php echo Route::url($base . '/' . $row->get('id') . '/edit'); ?>">
													<?php echo Lang::txt('PLG_GROUPS_FORUM_EDIT'); ?>
												</a>
											<?php } ?>
											<?php if ($this->config->get('access-delete-thread')) { ?>
												<a class="icon-delete delete" href="<?php echo Route::url($base . '/' . $row->get('id') . '/delete')  . $sortingQueryString; ?>">
													<?php echo Lang::txt('PLG_GROUPS_FORUM_DELETE'); ?>
												</a>
											<?php } ?>
										</td>
									<?php } ?>
								<?php } ?>
							</tr>
						<?php } ?>
					<?php } else { ?>
							<tr>
								<td><?php echo Lang::txt('PLG_GROUPS_FORUM_CATEGORY_EMPTY'); ?></td>
							</tr>
					<?php } ?>
				</tbody>
			</table>

			<?php
			$pageNav = $this->threads->pagination;
			$pageNav->setAdditionalUrlParam('cn', $this->group->get('cn'));
			$pageNav->setAdditionalUrlParam('active', 'forum');
			$pageNav->setAdditionalUrlParam('scope', $this->filters['section'] . '/' . $this->filters['category']);
			echo $pageNav;
			?>
		</div><!-- / .container -->
		<input type="hidden" name="sortdir" value="<?php echo $this->escape($this->filters['sort_Dir']); ?>" />
		<input type="hidden" name="sortby" value="<?php echo $this->escape($this->filters['sortby']); ?>" />
	</form>
</section><!-- /.main -->
